@@ -18,7 +18,6 @@ import math
 import os
 import sys
 import unittest
-
 from collections import OrderedDict
 from string import printable
 
@@ -28,7 +27,6 @@ try:
     # Make the `hypothesis` library optional, so that the other tests will
     # still run if it isn't installed.
     import hypothesis.strategies as some
-
     from hypothesis import given
 
     some_json = some.recursive(
@@ -254,6 +252,21 @@ class TestLoads(unittest.TestCase):
         self.check(u'\u2028 1', 1)
         self.check(u'\u2029 1', 1)
 
+    def test_error_reporting(self):
+        self.check_fail('[ ,]',
+            err='<string>:1 Unexpected "," at column 3')
+
+        self.check_fail(
+            '{\n'
+            '    version: "1.0",\n'
+            '    author: "John Smith",\n'
+            '    people : [\n'
+            '        "Monty",\n'
+            '        "Python"foo\n'
+            '    ]\n'
+            '}\n',
+            err='<string>:6 Unexpected "f" at column 17')
+
 
 class TestDump(unittest.TestCase):
     def test_basic(self):
@@ -334,13 +347,20 @@ class TestDumps(unittest.TestCase):
         self.assertEqual(json5.dumps(MyArray()), '[0, 1, 1]')
 
     def test_custom_numbers(self):
+        # See https://github.com/dpranke/pyjson5/issues/57: we
+        # need to ensure that we use the bare int.__repr__ and
+        # float.__repr__ in order to get legal JSON values when
+        # people have custom subclasses with customer __repr__ methods.
+        # (This is what JSON does and we want to match it).
         class MyInt(int):
-            pass
+            def __repr__(self):
+                return 'fail'
 
         self.assertEqual(json5.dumps(MyInt(5)), '5')
 
         class MyFloat(float):
-            pass
+            def __repr__(self):
+                return 'fail'
 
         self.assertEqual(json5.dumps(MyFloat(0.5)), '0.5')
 
@@ -375,7 +395,7 @@ class TestDumps(unittest.TestCase):
 
         self.assertRaises(TypeError, json5.dumps, set())
         self.assertEqual(json5.dumps(set(), default=_custom_serializer),
-                         'something')
+                         '"something"')
 
     def test_ensure_ascii(self):
         self.check(u'\u00fc', '"\\u00fc"')
@@ -414,6 +434,10 @@ class TestDumps(unittest.TestCase):
 
         self.assertRaises(ValueError, json5.dumps,
                           float('inf'), allow_nan=False)
+        self.assertRaises(ValueError, json5.dumps,
+                          float('-inf'), allow_nan=False)
+        self.assertRaises(ValueError, json5.dumps,
+                          float('nan'), allow_nan=False)
 
     def test_null(self):
         self.check(None, 'null')
